glfwSetMonitorUserPointer function
! @brief Sets the user pointer of the specified monitor.
This function sets the user-defined pointer of the specified monitor. The
current value is retained until the monitor is disconnected. The initial
value is NULL.
This function may be called from the monitor callback, even for a monitor that is being disconnected.
@paramin monitor The monitor whose pointer to set.
@paramin pointer The new value.
@errors Possible errors include @ref GLFW_NOT_INITIALIZED.
@thread_safety This function may be called from any thread. Access is not synchronized.
@sa @ref monitor_userptr @sa @ref glfwGetMonitorUserPointer
@since Added in version 3.3.
@ingroup monitor
GLFWAPI void glfwSetMonitorUserPointer(GLFWmonitor* monitor, void* pointer)
Implementation
void glfwSetMonitorUserPointer(
Pointer<GLFWmonitor> monitor, Pointer<Void> pointer) {
final glfwSetMonitorUserPointerLookupFunction = libglfw.lookupFunction<
Void Function(Pointer<GLFWmonitor> monitor, Pointer<Void> pointer),
void Function(Pointer<GLFWmonitor> monitor,
Pointer<Void> pointer)>('glfwSetMonitorUserPointer');
return glfwSetMonitorUserPointerLookupFunction(monitor, pointer);
}